@@ -19,6 +19,12 @@
  * 02111-1307, USA.
  */
 
+/*
+ * Port to Maemo Development Platform 
+ * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
+ */
+
+
 #include <gtk/gtk.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -52,6 +58,11 @@
 #include "gr_UnixImage.h"
 #include "gr_Painter.h"
 
+#ifdef HAVE_HILDON
+#include <hildon-widgets/hildon-file-chooser-dialog.h>
+#endif
+
+
 #include <sys/stat.h>
 
 #include "../../../wp/impexp/xp/ie_types.h"
@@ -61,6 +72,8 @@
 #define PREVIEW_WIDTH  100
 #define PREVIEW_HEIGHT 100
 
+
+
 /*****************************************************************/
 XAP_Dialog * XAP_UnixDialog_FileOpenSaveAs::static_constructor(XAP_DialogFactory * pFactory,
 															 XAP_Dialog_Id id)
@@ -91,7 +104,7 @@ static void s_dialog_response(GtkWidget * /* widget */,
 	{
 		case GTK_RESPONSE_CANCEL:
 		case GTK_RESPONSE_ACCEPT:
-
+		case GTK_RESPONSE_OK:
 			if (answer == GTK_RESPONSE_CANCEL)
 				*ptr = XAP_Dialog_FileOpenSaveAs::a_CANCEL;
 			else
@@ -104,9 +117,12 @@ static void s_dialog_response(GtkWidget * /* widget */,
 	}
 }
 
-static void s_delete_clicked(GtkWidget * /* widget*/, gpointer /* data */, XAP_Dialog_FileOpenSaveAs::tAnswer * answer)
+static void s_delete_clicked(GtkWidget 	*widget, 
+							 GdkEvent 	*event, 
+							 gpointer 	 data)
 {
-	*answer = XAP_Dialog_FileOpenSaveAs::a_CANCEL;
+	XAP_UnixDialog_FileOpenSaveAs *dlg = static_cast<XAP_UnixDialog_FileOpenSaveAs *>(data);
+	dlg->onDeleteCancel();
 	gtk_main_quit();
 }
 
@@ -462,6 +478,15 @@ void XAP_UnixDialog_FileOpenSaveAs::fileTypeChanged(GtkWidget * w)
 	}
 }
 
+void XAP_UnixDialog_FileOpenSaveAs::onDeleteCancel() 
+{
+	if (GTK_HAS_GRAB) {
+		gtk_grab_remove (GTK_WIDGET (m_FC));
+	}
+	m_FC = NULL;
+	m_answer = a_CANCEL;
+}
+
 /*****************************************************************/
 
 void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
@@ -550,6 +575,15 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	XAP_UnixFrameImpl * pUnixFrameImpl = static_cast<XAP_UnixFrameImpl *>(pFrame->getFrameImpl());
 	GtkWidget * parent = pUnixFrameImpl->getTopLevelWindow();
 
+#ifdef HAVE_HILDON
+	GtkWidget * wHildonView = gtk_widget_get_parent(parent);
+
+	m_FC = GTK_FILE_CHOOSER( hildon_file_chooser_dialog_new(GTK_WINDOW(wHildonView),
+							(m_id == XAP_DIALOG_ID_FILE_OPEN || m_id == XAP_DIALOG_ID_INSERT_PICTURE || m_id == XAP_DIALOG_ID_INSERT_FILE ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE))
+							);
+	
+#else	
+	
 	m_FC = GTK_FILE_CHOOSER( gtk_file_chooser_dialog_new (szTitle.utf8_str(),
 									GTK_WINDOW(parent),
 									(m_id == XAP_DIALOG_ID_FILE_OPEN || m_id == XAP_DIALOG_ID_INSERT_PICTURE || m_id == XAP_DIALOG_ID_INSERT_FILE ? GTK_FILE_CHOOSER_ACTION_OPEN : GTK_FILE_CHOOSER_ACTION_SAVE),
@@ -557,6 +591,7 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 									GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
 									NULL)
 							);
+#endif	
 
 	abiSetupModalDialog(GTK_DIALOG(m_FC), pFrame, this, GTK_RESPONSE_ACCEPT);
 	GtkWidget * filetypes_pulldown = NULL;
@@ -690,9 +725,9 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	
 	// connect the signals for OK and CANCEL and the requisite clean-close signals
 	g_signal_connect(G_OBJECT(m_FC),
-							 "delete_event",
+							 "delete-event",
 							 G_CALLBACK(s_delete_clicked),
-							 &m_answer);
+							 this);
 
 	g_signal_connect(G_OBJECT(m_FC),
 			    "key_press_event",
@@ -710,8 +745,8 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 	// use the persistence info and/or the suggested filename
 	// to properly seed the dialog.
 	
-	char * szPersistDirectory = NULL;	// we must free this
-	
+	gchar * szPersistDirectory = NULL;	// we must free this
+
 	if (!m_szInitialPathname || !*m_szInitialPathname)
 	{
 		// the caller did not supply initial pathname
@@ -725,11 +760,8 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 			// extract the directory portion and start
 			// the dialog there (but without a filename).
 
-			UT_cloneString(szPersistDirectory,m_szPersistPathname);
-			char * pLastSlash = strrchr(szPersistDirectory, '/');
-			if (pLastSlash)
-				pLastSlash[1] = 0;
-			gtk_file_chooser_set_filename(m_FC,szPersistDirectory);
+			szPersistDirectory = g_path_get_dirname(m_szPersistPathname);
+			gtk_file_chooser_set_current_folder(m_FC, szPersistDirectory);
 		}
 		else
 		{
@@ -748,18 +780,20 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 
 		if (m_bSuggestName)
 		{
-			// use m_szInitialPathname
+			if (!g_path_is_absolute (m_szInitialPathname)) {
+				gchar *dir = g_get_current_dir ();
+				gchar *file = m_szInitialPathname;
+				m_szInitialPathname = g_build_filename (dir, file, NULL);
+				g_free (dir);
+				g_free (file);
+			}
 			gtk_file_chooser_set_filename(m_FC, m_szInitialPathname);
 		}
 		else
 		{
 			// use directory(m_szInitialPathname)
-			
-			UT_cloneString(szPersistDirectory,m_szInitialPathname);
-			char * pLastSlash = strrchr(szPersistDirectory, '/');
-			if (pLastSlash)
-				pLastSlash[1] = 0;
-			gtk_file_chooser_set_filename(m_FC,szPersistDirectory);
+			szPersistDirectory = g_path_get_dirname(m_szInitialPathname);
+			gtk_file_chooser_set_current_folder(m_FC, szPersistDirectory);
 		}
 	}
 
@@ -786,9 +820,12 @@ void XAP_UnixDialog_FileOpenSaveAs::runModal(XAP_Frame * pFrame)
 		m_nFileType = GPOINTER_TO_INT(g_object_get_data(G_OBJECT(activeItem), "user_data"));
 	}
 
-	gtk_grab_remove (GTK_WIDGET(m_FC));
-	gtk_widget_destroy (GTK_WIDGET(m_FC));
-	FREEP(szPersistDirectory);
+	if (m_FC != NULL) {
+		gtk_grab_remove (GTK_WIDGET(m_FC));
+		gtk_widget_destroy (GTK_WIDGET(m_FC));
+		m_FC = NULL;
+		FREEP(szPersistDirectory);
+	}
 
 	return;
 }
