@@ -19,6 +19,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
  * 02111-1307, USA.
  */
+ 
+  /*
+  * Port to Maemo Development Platform 
+  * Author: INdT - Renato Araujo <renato.filho@indt.org.br>
+  */
 
 #include <gtk/gtk.h>
 #include <gdk/gdkx.h>
@@ -28,6 +33,8 @@
 #include <sys/stat.h>
 #include <string.h>
 
+#include "ap_Features.h"
+
 #include "ut_types.h"
 #include "ut_assert.h"
 #include "ut_files.h"
@@ -62,6 +69,8 @@
 #include <gnome.h>
 #include <libgnomevfs/gnome-vfs.h>
 #include <libgnomevfs/gnome-vfs-mime-utils.h>
+
+#include "ev_GnomeToolbar.h"
 #endif
 
 #ifdef HAVE_GNOME
@@ -671,6 +680,9 @@ gint XAP_UnixFrameImpl::_fe::configure_event(GtkWidget* w, GdkEventConfigure *e)
 // from the m_wTopLevelWindow widget.
 // -- MES
 //
+
+#ifdef HAVE_HILDON
+#else
         GtkWindow * pWin = NULL;
 		if(pFrame->getFrameMode() == XAP_NormalFrame)
 			pWin = GTK_WINDOW(pUnixFrameImpl->m_wTopLevelWindow);
@@ -680,6 +692,7 @@ gint XAP_UnixFrameImpl::_fe::configure_event(GtkWidget* w, GdkEventConfigure *e)
         gint gwidth,gheight;
         gtk_window_get_size(pWin,&gwidth,&gheight);
         pApp->setGeometry(e->x,e->y,gwidth,gheight,flags);
+#endif
 
 		// Dynamic Zoom Implementation
 
@@ -962,6 +975,8 @@ void XAP_UnixFrameImpl::_nullUpdate() const
 
 void XAP_UnixFrameImpl::_initialize()
 {
+	UT_DEBUGMSG (("XAP_UnixFrameImpl::_initialize()\n"));
+
     	// get a handle to our keyboard binding mechanism
  	// and to our mouse binding mechanism.
  	EV_EditEventMapper * pEEM = XAP_App::getApp()->getEditEventMapper();
@@ -1117,6 +1132,7 @@ void XAP_UnixFrameImpl::_setCursor(GR_Graphics::Cursor c)
 	GdkCursor * cursor = gdk_cursor_new(cursor_number);
 	gdk_window_set_cursor(getTopLevelWindow()->window, cursor);
 	gdk_window_set_cursor(getVBoxWidget()->window, cursor);
+
 	gdk_window_set_cursor(m_wSunkenBox->window, cursor);
 	gdk_window_set_cursor(m_wStatusBar->window, cursor);
 	gdk_cursor_unref(cursor);
@@ -1155,7 +1171,7 @@ XAP_DialogFactory * XAP_UnixFrameImpl::_getDialogFactory(void)
 }
 
 // TODO: split me up into smaller pieces/subfunctions
-void XAP_UnixFrameImpl::createTopLevelWindow(void)
+void XAP_UnixFrameImpl::_createTopLevelWindow(void)
 {
 	// create a top-level window for us.
 
@@ -1171,17 +1187,23 @@ void XAP_UnixFrameImpl::createTopLevelWindow(void)
 	}
 	
 	bool bResult;
+	
 	if(m_iFrameMode == XAP_NormalFrame)
 	{
 		m_wTopLevelWindow = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic_attr", NULL);
-		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic", NULL);
 		gtk_window_set_title(GTK_WINDOW(m_wTopLevelWindow),
 				     m_pUnixApp->getApplicationTitleForTitleBar());
 		gtk_window_set_resizable(GTK_WINDOW(m_wTopLevelWindow), TRUE);
 		gtk_window_set_role(GTK_WINDOW(m_wTopLevelWindow), "topLevelWindow");
 		if ( wmIcon )
 			gtk_window_set_icon(GTK_WINDOW(m_wTopLevelWindow), wmIcon);
+		
+		gtk_window_set_resizable(GTK_WINDOW(m_wTopLevelWindow), TRUE);
+		gtk_window_set_role(GTK_WINDOW(m_wTopLevelWindow), "topLevelWindow");		
+		
+		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic_attr", NULL);
+		g_object_set_data(G_OBJECT(m_wTopLevelWindow), "ic", NULL);		
+		
 	}
 	g_object_set_data(G_OBJECT(m_wTopLevelWindow), "toplevelWindow",
 						m_wTopLevelWindow);
@@ -1197,6 +1219,7 @@ void XAP_UnixFrameImpl::createTopLevelWindow(void)
 					   G_CALLBACK(_fe::unrealize), NULL);
 	g_signal_connect(G_OBJECT(m_wTopLevelWindow), "size_allocate",
 					   G_CALLBACK(_fe::sizeAllocate), NULL);
+
 	g_signal_connect(G_OBJECT(m_wTopLevelWindow), "focus_in_event",
 					   G_CALLBACK(_fe::focusIn), NULL);
 	g_signal_connect(G_OBJECT(m_wTopLevelWindow), "focus_out_event",
@@ -1498,6 +1521,7 @@ void XAP_UnixFrameImpl::_setGeometry ()
 
 	// Remember geometry settings for next time
 	m_pUnixApp->getPrefs()->setGeometry (user_x, user_y, user_w, user_h, user_f);
+			
 }
 
 /*!
@@ -1559,9 +1583,7 @@ bool XAP_UnixFrameImpl::_close()
 bool XAP_UnixFrameImpl::_raise()
 {
 	UT_ASSERT(m_wTopLevelWindow);
-
-	gtk_window_present(GTK_WINDOW (m_wTopLevelWindow));
-
+	gtk_window_present(GTK_WINDOW (m_wTopLevelWindow));	
 	return true;
 }
 
@@ -1698,5 +1720,11 @@ EV_Toolbar * XAP_UnixFrameImpl::_newToolbar(XAP_App *pApp, XAP_Frame *pFrame,
 					      const char *szLayout,
 					      const char *szLanguage)
 {
-	return (new EV_UnixToolbar(static_cast<XAP_UnixApp *>(pApp), pFrame, szLayout, szLanguage));
+	EV_UnixToolbar *pToolbar = NULL;
+#ifdef HAVE_GNOME
+	pToolbar = new EV_GnomeToolbar(static_cast<XAP_UnixApp *>(pApp), pFrame, szLayout, szLanguage);
+#else
+	pToolbar = new EV_UnixToolbar(static_cast<XAP_UnixApp *>(pApp), pFrame, szLayout, szLanguage);
+#endif
+	return pToolbar;
 }
