@@ -22,16 +22,24 @@
 #ifndef FL_AUTONUM_H
 #define FL_AUTONUM_H
 
+#include <vector>
 #include "ut_types.h"
 #include "ut_misc.h"
 #include "ut_vector.h"
 #include "pt_Types.h"
 #include "fl_AutoLists.h"
+#include "ut_string_class.h"
+using namespace std;
+using std::vector;
+
+typedef pair< PL_StruxDocHandle, UT_UCS4String > FL_SDHLabelPair;
+typedef vector< FL_SDHLabelPair > FL_LabelMap;
 
 // fwd. decl.
 class fl_BlockLayout;
 class fl_Layout;
 class PD_Document;
+class FV_View;
 
 
 class ABI_EXPORT fl_AutoNum
@@ -43,16 +51,18 @@ public:
 				fl_AutoNum * pParent,
 				const XML_Char * lDelim,
 				const XML_Char * lDecimal,
-				List_Type lType,
-				PD_Document * pDoc);
+				FL_ListType lType,
+				PD_Document * pDoc,
+				FV_View * pView);
 
 	fl_AutoNum(	UT_uint32 id,
 				UT_uint32 parent_id,
-				List_Type lType,
+				FL_ListType lType,
 				UT_uint32 start,
 				const XML_Char * lDelim,
 				const XML_Char * lDecimal,
-				PD_Document * pDoc);
+				PD_Document * pDoc,
+				FV_View * pView);
 
 	~fl_AutoNum();
 
@@ -60,7 +70,7 @@ public:
 
 	const UT_UCSChar *			getLabel(PL_StruxDocHandle) const;
 	void						addItem(PL_StruxDocHandle pItem);
-	List_Type					getType() const;
+	FL_ListType					getType() const;
 	UT_uint32					getValue(PL_StruxDocHandle) const;
 	UT_uint32					getLevel() const { return m_iLevel; }
 	UT_uint32					getNumLabels() const;
@@ -68,7 +78,7 @@ public:
 
 	void						setLevel(UT_uint32 level) { m_iLevel = level; }
 	UT_sint32					getPositionInList( PL_StruxDocHandle pItem, UT_uint32 depth) const;
-	void						setListType(List_Type lType);
+	void						setListType(FL_ListType lType);
 	void						setDelim(const XML_Char * pszDelim);
 	const XML_Char *			getDelim() const;
 	void						setDecimal(const XML_Char * pszDecimal);
@@ -112,10 +122,12 @@ public:
 	bool						isUpdating(void) { return m_bUpdatingItems; }
 	UT_uint32					getID() const { return m_iID; }
 	UT_uint32					getParentID() const { return m_iParentID; }
+	bool                        isIDSomeWhere(UT_uint32 ID);
 	static char *				dec2roman(UT_sint32 value, bool lower);
 	static char *				dec2ascii(UT_sint32 value, UT_uint32 offset);
 	static void					dec2hebrew(UT_UCSChar labelStr[], UT_uint32 * insPoint, UT_sint32 value);
 	const char **				getAttributes(void) ;
+	PL_StruxDocHandle                       getLastItemInHeiracy(void);
 
 protected:
 	void                        _setParent(fl_AutoNum * pParent);
@@ -128,11 +140,12 @@ protected:
 	void						_updateItems(UT_uint32 start, PL_StruxDocHandle notMe );
 	UT_uint32					_getLevelValue(fl_AutoNum * pAutoNum);
 
-	fl_AutoNum *				m_pParent;
+	fl_AutoNum *					m_pParent;
 
 	UT_Vector					m_pItems;
-	PD_Document *				m_pDoc;
-	List_Type					m_List_Type;
+	PD_Document *               		m_pDoc;
+	FV_View *				    	m_pView;
+	FL_ListType					m_List_Type;
 	UT_uint32					m_iID;
 	UT_uint32					m_iParentID;
 	UT_uint32					m_iLevel;
@@ -145,7 +158,7 @@ protected:
 	XML_Char					m_pszDelim[80];
 	XML_Char					m_pszIndent[80];
 	bool						m_bWordMultiStyle;
-	PL_StruxDocHandle			m_pParentItem;
+	PL_StruxDocHandle				m_pParentItem;
 };
 
 #endif
