@@ -45,6 +45,7 @@ enum _AP_Dialog_Id
 	AP_DIALOG_ID_COLUMNS,				/* Columns Dialog */
 	AP_DIALOG_ID_PAGE_NUMBERS, /* Page Numbers/ Header Footer Dialog */
 	AP_DIALOG_ID_STYLES,       /* define/edit/delete styles */
+	AP_DIALOG_ID_STYLIST,
 	AP_DIALOG_ID_AUTOTEXT,   /* insert some autotext */
 	AP_DIALOG_ID_TOGGLECASE, /* change the case of a run of text */
 	AP_DIALOG_ID_BACKGROUND, /* change the doc's bg color */
@@ -56,9 +57,13 @@ enum _AP_Dialog_Id
 	AP_DIALOG_ID_LIST_REVISIONS,
 	AP_DIALOG_ID_INSERT_TABLE,
 	AP_DIALOG_ID_MERGE_CELLS,
+	AP_DIALOG_ID_SPLIT_CELLS,
 	AP_DIALOG_ID_FORMAT_TABLE,
+	AP_DIALOG_ID_FORMAT_FRAME,
 	AP_DIALOG_ID_FORMAT_FOOTNOTES,	
+	AP_DIALOG_ID_FORMAT_TOC,	
 	AP_DIALOG_ID_MAILMERGE,
+	AP_DIALOG_ID_LATEX, /*Insert and modify a latex based equation */
 #if 0
 	AP_DIALOG_ID_DOWNLOAD_FILE,			/* threaded download of a file, with a cancel-button */	
 #endif
