@@ -422,6 +422,7 @@ dcl(DLG_Options_Label_ViewStandardTB,		"Standard Toolbar")
 dcl(DLG_Options_Label_ViewFormatTB, 	"Format Toolbar")
 dcl(DLG_Options_Label_ViewTableTB,		"Table Toolbar")
 dcl(DLG_Options_Label_ViewExtraTB,		"Extra Toolbar")
+dcl(DLG_Options_Label_ViewSimpleTB,		"Simple Toolbar")
 dcl(DLG_Options_Label_ViewStatusBar,		"&Status bar")
 dcl(DLG_Options_Label_ViewViewFrame,	"View...")
 dcl(DLG_Options_Label_ViewAll,			"&All")
@@ -963,6 +964,7 @@ dcl(MENU_LABEL_FMT_SUPERSCRIPT,"Supe&rscript")
 dcl(MENU_LABEL_FMT_SUBSCRIPT,"&Subscript")
 dcl(MENU_LABEL_FMT_FRAME,"Text Box")
 dcl(MENU_LABEL_FMT_IMAGE, "&Image")
+dcl(MENU_LABEL_FMT_SETPOSIMAGE, "Set Positioned Image")
 dcl(MENU_LABEL_FMT_POSIMAGE, "&Image")
 dcl(MENU_LABEL_FMT_DIRECTION, "D&irectional")
 dcl(MENU_LABEL_FMT_DIRECTION_DD_RTL, "RTL &Paragraph")
@@ -1359,11 +1361,13 @@ dcl(MENU_STATUSLINE_SPELL_IGNOREALL,"Ignore all occurrences of this word in the
 dcl(MENU_STATUSLINE_SPELL_ADD,"Add this word to the custom dictionary")
 dcl(MENU_STATUSLINE_FMT_IMAGE, "Resize this image")
 dcl(MENU_STATUSLINE_FMT_POSIMAGE, "Format this image")
+dcl(MENU_STATUSLINE_FMT_SETPOSIMAGE, "Set this image to be positioned")
 
 /* Toolbar labels */
 dcl(TB_Extra,"Extra")
 dcl(TB_Format,"Format")
 dcl(TB_Standard,"Standard")
+dcl(TB_Simple,"Simple")
 dcl(TB_Table,"Table")
 
 dcl(TOOLBAR_LABEL_FILE_NEW,"New")
@@ -1384,6 +1388,7 @@ dcl(TOOLBAR_LABEL_EDIT_REMOVEFOOTER,"Remove Footer")
 dcl(TOOLBAR_LABEL_SPELLCHECK,"Spellcheck")
 dcl(TOOLBAR_LABEL_IMG,"Insert Image")
 dcl(TOOLBAR_LABEL_FMT_STYLE,"Style")
+dcl(TOOLBAR_LABEL_FMT_CHOOSE,"Font choose")
 dcl(TOOLBAR_LABEL_FMT_FONT,"Font")
 dcl(TOOLBAR_LABEL_FMT_HYPERLINK,"Insert Hyperlink")
 dcl(TOOLBAR_LABEL_FMT_BOOKMARK,"Insert Bookmark")
@@ -1413,6 +1418,7 @@ dcl(TOOLBAR_LABEL_2COLUMN,"2 Columns")
 dcl(TOOLBAR_LABEL_3COLUMN,"3 Columns")
 dcl(TOOLBAR_LABEL_VIEW_SHOWPARA,"Show All")
 dcl(TOOLBAR_LABEL_ZOOM,"Zoom")
+dcl(TOOLBAR_LABEL_VIEW_FULL_SCREEN,"Full Screen")
 dcl(TOOLBAR_LABEL_LISTS_BULLETS,"Bullets")
 dcl(TOOLBAR_LABEL_LISTS_NUMBERS,"Numbering")
 dcl(TOOLBAR_LABEL_COLOR_FORE,"Font color")
@@ -1454,6 +1460,7 @@ dcl(TOOLBAR_STATUSLINE_EDIT_REMOVEFOOTER,"Remove Footer")
 dcl(TOOLBAR_STATUSLINE_SPELLCHECK,"Spellcheck the document")
 dcl(TOOLBAR_STATUSLINE_IMG,"Insert an image into the document")
 dcl(TOOLBAR_STATUSLINE_FMT_STYLE,"Style")
+dcl(TOOLBAR_STATUSLINE_FMT_CHOOSE,"Font Choose")
 dcl(TOOLBAR_STATUSLINE_FMT_FONT,"Font")
 dcl(TOOLBAR_STATUSLINE_FMT_HYPERLINK,"Insert a hyperlink into the document")
 dcl(TOOLBAR_STATUSLINE_FMT_BOOKMARK,"Insert a bookmark into the document")
@@ -1483,6 +1490,7 @@ dcl(TOOLBAR_STATUSLINE_2COLUMN,"2 Columns")
 dcl(TOOLBAR_STATUSLINE_3COLUMN,"3 Columns")
 dcl(TOOLBAR_STATUSLINE_VIEW_SHOWPARA,"Show/hide formatting marks")
 dcl(TOOLBAR_STATUSLINE_ZOOM,"Zoom")
+dcl(TOOLBAR_STATUSLINE_VIEW_FULL_SCREEN,"Full Screen")
 dcl(TOOLBAR_STATUSLINE_LISTS_BULLETS,"Bullets")
 dcl(TOOLBAR_STATUSLINE_LISTS_NUMBERS,"Numbering")
 dcl(TOOLBAR_STATUSLINE_COLOR_FORE,"Font color")
@@ -1524,6 +1532,7 @@ dcl(TOOLBAR_TOOLTIP_EDIT_REMOVEFOOTER,"Remove Footer")
 dcl(TOOLBAR_TOOLTIP_SPELLCHECK,"Spellcheck the document")
 dcl(TOOLBAR_TOOLTIP_IMG,"Insert an image into the document")
 dcl(TOOLBAR_TOOLTIP_FMT_STYLE,"Style")
+dcl(TOOLBAR_TOOLTIP_FMT_CHOOSE,"Select Font")
 dcl(TOOLBAR_TOOLTIP_FMT_FONT,"Font")
 dcl(TOOLBAR_TOOLTIP_FMT_HYPERLINK,"Insert a hyperlink into the document")
 dcl(TOOLBAR_TOOLTIP_FMT_BOOKMARK,"Insert a bookmark into the document")
@@ -1553,6 +1562,7 @@ dcl(TOOLBAR_TOOLTIP_2COLUMN,"2 Columns")
 dcl(TOOLBAR_TOOLTIP_3COLUMN,"3 Columns")
 dcl(TOOLBAR_TOOLTIP_VIEW_SHOWPARA,"Show/hide formatting marks")
 dcl(TOOLBAR_TOOLTIP_ZOOM,"Zoom")
+dcl(TOOLBAR_TOOLTIP_VIEW_FULL_SCREEN,"Full Screen")
 dcl(TOOLBAR_TOOLTIP_LISTS_BULLETS,"Bullets")
 dcl(TOOLBAR_TOOLTIP_LISTS_NUMBERS,"Numbering")
 dcl(TOOLBAR_TOOLTIP_COLOR_FORE,"Font color")
